pub struct ProjectivePoint { /* private fields */ }Available on crate feature
arithmetic only.Expand description
A point on the secp256k1 curve in projective coordinates.
Implementations
Sourceimpl ProjectivePoint
impl ProjectivePoint
Sourcepub fn mul_by_generator(k: &Scalar) -> ProjectivePoint
pub fn mul_by_generator(k: &Scalar) -> ProjectivePoint
Calculates k * G, where G is the generator.
Sourcepub fn mul_by_generator_vartime(k: &Scalar) -> ProjectivePoint
pub fn mul_by_generator_vartime(k: &Scalar) -> ProjectivePoint
Calculates k * G in variable-time, where G is the generator.
Sourceimpl ProjectivePoint
impl ProjectivePoint
Sourcepub fn to_affine(&self) -> AffinePoint
pub fn to_affine(&self) -> AffinePoint
Returns the affine representation of this point.
Sourcepub fn double(&self) -> ProjectivePoint
pub fn double(&self) -> ProjectivePoint
Doubles this point.
Sourcepub fn double_in_place(&mut self)
pub fn double_in_place(&mut self)
Doubles this point in-place.
Sourcepub fn endomorphism(&self) -> Self
pub fn endomorphism(&self) -> Self
Calculates SECP256k1 endomorphism: self * lambda.
Sourcepub fn eq_affine(&self, other: &AffinePoint) -> Choice
pub fn eq_affine(&self, other: &AffinePoint) -> Choice
Check whether self is equal to an affine point.
This is a lot faster than first converting self to an AffinePoint and then doing the
comparison. It is a little bit faster than converting other to a ProjectivePoint first.